<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ne">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>थप साधनहरू</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="15"/>
        <source>Advanced Settings</source>
        <translation>उन्नत सेटिङहरू</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>&quot;उन्नत सेटिङहरू&quot; सिस्टम सेटिङहरू प्रयोग गर्ने इनपुट विधिका लागि मात्र लागू हुन्छ। यदि इनपुट विधिको आफ्नै सेटिङहरू छन् भने, त्यसको आफ्नै सेटिङहरूले प्राथमिकता पाउँछ।</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="54"/>
        <source>Global Config</source>
        <translation>विश्वव्यापी कन्फिगरेसन</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="70"/>
        <source>Add-ons</source>
        <translation>थप साधनहरू</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="81"/>
        <source>Keyboard layout</source>
        <translation>किबोर्ड लेआउट</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="151"/>
        <source>Please enter a new shortcut</source>
        <translation>कृपया नयाँ सर्टकट प्रविष्ट गर्नुहोस्</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="152"/>
        <source>Move Up</source>
        <translation>माथि सार्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="160"/>
        <source>Move Down</source>
        <translation>तल सार्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="168"/>
        <source>Settings</source>
        <translation>सेटिङहरू</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="176"/>
        <source>Remove</source>
        <translation>हटाउनुहोस्</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
        <source>Add input method</source>
        <translation>इनपुट विधि थप्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
        <source>Search</source>
        <translation>खोज्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
        <source>Find more in App Store</source>
        <translation>एप स्टोरमा थप फेला पार्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
        <source>Add</source>
        <translation>थप्नुहोस्</translation>
    </message>
</context>
<context>
    <name>KeyboardLayout</name>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>किबोर्ड लेआउट</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>done</source>
        <translation>सम्पन्न</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>edit</source>
        <translation>सम्पादन गर्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>किबोर्ड लेआउट थप्दा वा स्विच गर्दा काम गर्ने सुनिश्चित गर्न &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;इनपुट विधि प्रबन्धन&lt;/a&gt; मा सम्बन्धित इनपुट विधि थप्नुहोस्।</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="142"/>
        <source>Add new keyboard layout...</source>
        <translation>नयाँ किबोर्ड लेआउट थप्नुहोस्...</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutModule</name>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>किबोर्ड लेआउट</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>done</source>
        <translation>सम्पन्न</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>edit</source>
        <translation>सम्पादन गर्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>किबोर्ड लेआउट थप्दा वा स्विच गर्दा काम गर्ने सुनिश्चित गर्न &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;इनपुट विधि प्रबन्धन&lt;/a&gt; मा सम्बन्धित इनपुट विधि थप्नुहोस्।</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="140"/>
        <source>Add new keyboard layout...</source>
        <translation>नयाँ किबोर्ड लेआउट थप्नुहोस्...</translation>
    </message>
</context>
<context>
    <name>LayoutsChooser</name>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="30"/>
        <source>Add new keyboard layout</source>
        <translation>नयाँ किबोर्ड लेआउट थप्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="38"/>
        <source>Search</source>
        <translation>खोज्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="67"/>
        <source>Current language keyboard layouts</source>
        <translation>हालको भाषाको किबोर्ड लेआउटहरू</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="90"/>
        <source>Cancel</source>
            <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="97"/>
        <source>Add</source>
        <translation>थप्नुहोस्</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>इनपुट विधि प्रबन्धन</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
        <source>Add input method</source>
        <translation>इनपुट विधि थप्नुहोस्</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="12"/>
        <location filename="../qml/ShortcutsModule.qml" line="14"/>
        <location filename="../qml/ShortcutsModule.qml" line="151"/>
        <location filename="../qml/ShortcutsModule.qml" line="152"/>
        <source>None</source>
        <translation>कुनै पनि छैन</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="119"/>
        <source>Shortcuts</source>
        <translation>सर्टकटहरू</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="134"/>
        <source>Restore Defaults</source>
        <translation>पूर्वनिर्धारित पुनर्स्थापना गर्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="200"/>
        <source>Scroll between input methods</source>
        <translation>इनपुट विधिहरू बीच स्क्रोल गर्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="230"/>
        <source>Turn on or off input methods</source>
        <translation>इनपुट विधिहरू खोल्नुहोस् वा बन्द गर्नुहोस्</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="273"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>यसले हाल प्रयोग भइरहेको इनपुट विधिलाई खोल्छ वा बन्द गर्छ। यदि कुनै इनपुट विधि प्रयोग भइरहेको छैन वा पहिलो इनपुट विधि किबोर्ड होइन भने, यसले पहिलो इनपुट विधि र हाल प्रयोग भइरहेको किबोर्ड/इनपुट विधि बीच स्विच गर्छ।</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::dialectNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="62"/>
        <source>Traditional Chinese (Chinese Hong Kong)</source>
        <translation>परम्परागत चिनियाँ (चिनियाँ हङकङ)</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="65"/>
        <source>Traditional Chinese (Chinese Taiwan)</source>
        <translation>परम्परागत चिनियाँ (चिनियाँ ताइवान)</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::regionNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="86"/>
        <source>Taiwan China</source>
        <translation>ताइवान चीन</translation>
    </message>
</context>
<context>
    <name>dccV25::KeyboardController</name>
    <message>
        <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
        <source>This shortcut conflicts with [%1]</source>
            <translation>यो सर्टकट [%1] सँग बाझिन्छ</translation>
    </message>
</context>
<context>
    <name>dccV25::ShortcutModel</name>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="248"/>
        <source>System</source>
        <translation>प्रणाली</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="253"/>
        <source>Window</source>
        <translation>विन्डो</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="258"/>
        <source>Workspace</source>
        <translation>कार्यक्षेत्र</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="263"/>
        <source>AssistiveTools</source>
        <translation>सहायक उपकरणहरू</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="268"/>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="339"/>
        <source>Custom</source>
        <translation>अनुकूलन</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="394"/>
        <source>None</source>
        <translation>कुनै पनि छैन</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>इनपुट विधिहरू</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>इनपुट विधि प्रबन्धन, इनपुट विधि सर्टकटहरू, उन्नत सेटिङहरू</translation>
    </message>
</context>
</TS>